// PAIN 
// If you were only given today's open, high, low and close, how could you make heads or 
// tails of it? The Price Action Indicator (PAIN) can help. 
// The formula returns a single value that weighs intra-day momentum (C-O), Late Selling Pressure (LSP) (C-L), 
// and Late Buying Pressure (LBP) (C-H). The formula is proven by constructing ideal limit-up and limit down 
// scenarios in bond futures. The output is shown to be consistent with the interpretation of Japanese 
// candlestick patterns. See Michael B. Geraty (1997). "Getting Better Directions" Futures Vol. 26: Aug.


// www.forexrealm.com/technical-analysis/technical-indicators/price-action-indicator.html


function init()
{
    with (PAIN) {
        createBuffer("PAIN");
        setBufferColor("PAIN", "#00FF00");
        setBufferDrawStyle("PAIN", DrawStyle.LINE);
        setAutoChangeMaxMin("PAIN");
    }
}

function start()
{
    PAIN.label = "PAIN";
    PAIN.addLevel(0, "#1FFF00"); 

    var num = Shared.numberOfQuotes();
    var PAINBuf = new Array(num);

    var OpenBuf = Shared.open();
    var CloseBuf = Shared.close();
    var HighBuf = Shared.high();
    var LowBuf = Shared.low();

    for (var i = 0; i < num; ++i) {
      PAINBuf[i] = ((CloseBuf[i]-OpenBuf[i]) + (CloseBuf[i]-HighBuf[i]) + (CloseBuf[i]-LowBuf[i])) / 2 ;
    }

    PAIN.setBufferData("PAIN", PAINBuf);
}
